# Serial-for-controller [![old api](https://img.shields.io/badge/old-api-blue?style=for-the-badge&logoColor=white)](https://github.com/Adam-Software) [![Platforms](https://img.shields.io/badge/Raspberry%20Pi-A22846?style=for-the-badge&logo=Raspberry%20Pi&logoColor=white)](https://img.shields.io/badge/Raspberry%20Pi-A22846?style=for-the-badge&logo=Raspberry%20Pi&logoColor=white) [![Language](https://img.shields.io/badge/Python-3776AB?style=for-the-badge&logo=python&logoColor=white)](https://img.shields.io/badge/Python-3776AB?style=for-the-badge&logo=python&logoColor=white) [![adam package](https://img.shields.io/badge/adam_package-red?style=for-the-badge&logo=python&logoColor=white)](https://github.com/Adam-Software)


[![License](https://img.shields.io/github/license/Adam-Software/Serial-for-controller)](https://img.shields.io/github/license/Adam-Software/Serial-for-controller)
[![Activity](https://img.shields.io/github/commit-activity/m/Adam-Software/Serial-for-controller)](https://img.shields.io/github/commit-activity/m/Adam-Software/Serial-for-controller)
[![LastStatus](https://img.shields.io/github/last-commit/Adam-Software/Serial-for-controller)](https://img.shields.io/github/last-commit/Adam-Software/Serial-for-controller)
[![CodeSize](https://img.shields.io/github/languages/code-size/Adam-Software/Serial-for-controller)](https://img.shields.io/github/languages/code-size/Adam-Software/Serial-for-controller)
[![Depencies](https://img.shields.io/librariesio/github/Adam-Software/Serial-for-controller)](https://img.shields.io/librariesio/github/Adam-Software/Serial-for-controller)

[![PyPI version](https://badge.fury.io/py/serial-for-controller.svg)](https://badge.fury.io/py/serial-for-controller)
[![PythonVersion](https://img.shields.io/pypi/pyversions/serial-for-controller)](https://img.shields.io/pypi/pyversions/serial-for-controller)
[![Wheel](https://img.shields.io/pypi/wheel/serial-for-controller)](https://img.shields.io/pypi/wheel/serial-for-controller)
[![Status](https://img.shields.io/pypi/status/serial-for-controller)](https://img.shields.io/pypi/status/serial-for-controller)
[![Format](https://img.shields.io/pypi/format/serial-for-controller)](https://img.shields.io/pypi/format/serial-for-controller)
### What the library can do?

Python library for data exchange with STM32 controller.

### How install?

Old version package, with full name compatibility

```commandline
pip install Adam-Serial-for-controller
```

New version package, without name compatibility

```commandline
pip install serial-for-controller
```

### How import?

Old version

```commandline
from Serial.serialPi import SerialU
```

New version

```commandline
from serial_for_controller.SerialPi import SerialPi
```

### Versions

For old package Adam-Serial-for-controller last version 0.2.1
For the new version Serial-for-controller, the countdown started from 0.0.1

Thus, the functionality of version 0.2.1 corresponds to version 0.0.1 only with other names of functions and classes